<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autors</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Navegador web lleuger basat en WebKit</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Idiomes</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Idiomes en odre de preferència:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mou am&amp;unt</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mou a&amp;vall</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Esbo&amp;rra</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Afegeix...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Regla</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Afegeix carpeta</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Afegeix punt</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Introduïu un nom pel punt i escolliu on desar-lo.</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Elimina</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Obre en una pestanya nova</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Edita nom</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Edita adreça</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Carpeta nova</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Punts</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Afegeix carpeta</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Barra de punts</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menú de punts</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Error en carregar punts a la línia %1, columna %2: %3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Barra d&apos;eines de punts</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Obre fitxer</translation>
    </message>
    <message>
        <source>XBEL</source>
        <translation type="obsolete">XBEL</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Error en carregar punts html: %1</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importat: %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Punts.xbel</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Error d&apos;exportació</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Erro en desar els punts</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Elimina punt</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Insereix punt</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Canvia l&apos;adreça</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Obre en pestanyes</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Punt</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Obre en una nova pes&amp;tanya</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Afegeix punt...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Afegeix carpeta...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Punts</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Hi ha obertes %1 finestres i %2 pestanyes 
Voleu sortir igualment?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Ha fallat la restauració</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">La sessió desada no es restablirà perquè l&apos;Arora va petar mentre tractava de restaurar aquesta sessió.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>Default</source>
        <translation>Predeterminat</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nova finestra</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Obre fitxer...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Obre &amp;localització...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Desa com a...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importa punts...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exporta punts...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Vista p&amp;rèvia d&apos;impressió...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primeix...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Nave&amp;gació.privada...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Tanca la finestra</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Abandona</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Desfés</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refés</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Talla</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Enganxa</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Cerca Següen&amp;t</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Ce&amp;rca Anterior</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Preferè&amp;ncies...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualitza</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Maj+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Mostra la barra de menú</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Recarrega la pàgina</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>A&amp;tura</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Apropa</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Zoom &amp;Normal</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>A&amp;llunya</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Zoom només el &amp;text</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>C&amp;odi font de la pàgina</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codificació del text</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>Hi&amp;storial</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Endavant</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Restaura l&apos;última sessió</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Punts</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Mostra tots els punts...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Afegeix punt...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Afegeix carpeta...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Eines</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Cerca a la web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Neteja les dades privades</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Maj+Supr</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Mostra el mo&amp;nitor de xarxa</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Hab&amp;ilita l&apos;inspector web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Canvia l&apos;idioma de l&apos;aplicació </translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Quant a &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Quant a &amp;%1</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navegació</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Mostra la barra d&apos;estat</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Oculta la barra d&apos;estat</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Mostra barra d&apos;eines</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Oculta Barra d&apos;eines</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Mostra la barra de punts</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Oculta la barra de punts</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Obre recurs web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Recursos web (*.html *.htm *.svg *.png *.gif *.svgz);;Tots els fitxers (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Imprimeix document</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Esteu segur que voleu activar la navegació privada?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Quan la navegació privada està activada, algunes accions corresponents a la privadesa es deshabilitaran:&lt;ul&gt;&lt;li&gt;Les pàgines web no s&apos;afegeixen a l&apos;historial.&lt;/li&gt;&lt;li&gt;Els ítems son eliminats automàticament de la finestra de baixades.&lt;/li&gt;&lt;li&gt;No es desen les noves galetes, no es pot accedir a les galetes actuals.&lt;/li&gt;&lt;li&gt;Les icones dels llocs no es poden desar, les sessions no es poden desar.&lt;/li&gt;&lt;li&gt;Les cerques no s&apos;afegeixen al menú desplegable a la caixa de cerca.&lt;/li&gt;&lt;/ul&gt;Fins que no tanqueu la finestra, podeu clicar als botons Enrere i Endavant per tornar a les pàgines web que heu obert.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Esteu segur que voleu tancar la finestra? Hi ha %1 pestanyes obertes</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Inspector web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>L&apos;inspector web només funciona correctament per pagines carregades després d&apos;habilitar-lo. 
Voleu recarregar totes les pàgines?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Atura la càrrega de la pàgina actual</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Recarrega la pàgina actual</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>


Download Manager
</comment>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation type="unfinished">Ctrl+Y</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished">Configura els motors de cerca...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Neteja</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Neteja les dades privades</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Neteja els següents ítems:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Historial de &amp;navegació</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Historial de baixa&amp;des</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Hi&amp;storial de cerca</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Galetes</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>P&amp;àgines web en memòria cau</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;Icones dels llocs web</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Neteja les dades &amp;privades</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel·la</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Carrega</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Carrega-ho tot</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Afegeix %1 a la llista blanca</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Elimina de la llista blanca</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arranjament</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Carrega Flash</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Llista blanca de llocs</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regla</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permet</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permet per aquesta sessió</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ruta</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>És segura</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Continguts</translation>
    </message>
    <message>
        <source>true</source>
        <translation>cert</translation>
    </message>
    <message>
        <source>false</source>
        <translation>fals</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Galeta de sessió</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Galetes</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Esborra totes les g&amp;aletes</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Afegeix &amp;regla</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Excepcions de galetes</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nova excepció</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domini:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permet per aquesta sessió</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permet</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Excepcions</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Elimin&amp;a-ho tot</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Neteja</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 ítems</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nom del fitxer</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Torna a intentar-ho</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>S&apos;ha cancel·lat la baixada: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Error en obrir el fitxer  de sortida: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Error en desar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Error de xarxa: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 de %2 (%3/seg) - %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - aturat</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Hi ha %1 baixades en curs 
Voleu abandonar igualment?</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform>%n baixada(es)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation type="unfinished">
            <numerusform>%n minuts restants</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation type="unfinished">
            <numerusform>%n segons restants</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Elimin&amp;a-ho tot</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Mostra tot l&apos;historial</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Neteja l&apos;historial...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Neteja l&apos;historial</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Voleu netejar l&apos;historial?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Títol</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Anterior a avui</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation type="unfinished">
            <numerusform>%n ítem(s)</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">No s&apos;han instal·lat fitxers de traducció.</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Seleccioneu l&apos;idioma</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Podeu treballar amb un idioma diferent al&lt;br&gt;predeterminat del sistema.&lt;/p&gt;&lt;p&gt;Si us plau, seleccioneu un idioma a usar&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduïu nom d&apos;usuari i contrasenya per \&quot;%1\&quot; a \&quot;%2\&quot;&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Connecta al proxy \&quot;%1\&quot; usant:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - errors SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Errors SSL:&lt;br/&gt;&lt;br/&gt;per: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt; 

Voleu ignorar aquests errors?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certificats:&lt;br/&gt;%1&lt;br/&gt;Voleu acceptar aquests certificats?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nom</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Valor</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Monitor de xarxa</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Peticions de xarxa</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Capçaleres de petició</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Capçaleres de resposta</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Elimin&amp;a Totes les peticions</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Obre fitxer</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 no és una descripció OpenSearch 1.1 vàlida o ja està a la llista.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Heu de tenir almenys un motor de cerca aquí.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Gestor OpenSearch</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Afegeix</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Es&amp;borra</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Restaura els valors predeterminats</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tanca</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Descripció:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Proporciona suggeriments contextuals&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Nom</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Voleu afegir el següent motor a la llista de motors de cerca?&lt;br/&gt;&lt;br /&gt;Nom: %1&lt;br /&gt;Cerca a: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Es requereix autenticació</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>ICONA SIMULADA</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>TEXT INTRODUÏT SIMULAT</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>No s&apos;ha trobat</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticació proxy</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Connecta a proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>El fitxer no és un fitxer XBEL versió 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Títol desconegut</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>El fitxer no és un fitxer Opensearch 1,1.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Redirecciona: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Mètode</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adreça</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Resposta</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Durada</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Tipus de contingut</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Informació</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>En iniciar:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Mostra la meva pàgina d&apos;inici</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Mostra una pàgina en blanc</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Restaura les finestres i les pestanyes de la darrera vegada</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pàgina d&apos;inici:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Estableix a la pàgina actual</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Elimina ítems de l&apos;historial:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Després d&apos;un dia</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Després d&apos;una setmana</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Després de dos setmanes</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Després d&apos;una mes</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Després d&apos;un any</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manualment</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>En sortir del programa</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Pregunta el destí cada vegada</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Usa aquesta destí:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Tipus de lletra estàndard:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Selecciona...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Tipus d&apos;amplada fixa:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Idiomes preferits per mostrar les pàgines web:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privadesa</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Contingut web</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Bloqueja les finestres emergents</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Habilita connectors</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Usa ClickToFlash en els connectors Flash</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Habilita el Javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Mostra les imatges</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Galetes</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Accepta galetes:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Només dels llocs que visiteu</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Excepcions...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Conserva les galetes fins que:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Expirin</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Es tanqui el programa</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Com a molt 90 dies</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Galetes...</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtra les galetes de seguiment</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestanyes</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Selecciona les pestanyes i les finestres en crear-les</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Demana confirmació en tancar múltiples pestanyes o finestres</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Mostra només un botó de tancament enlloc d&apos;un per cada pestanya</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Abandona el programa en tancar la darrera pestanya</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Opertura d&apos;enllaços</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Enllaços que volen obrir-se en una nova finestra:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>En una nova finestra</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>En una pestanya nova seleccionada de la finestra actual</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>En una nova pestanya de la finestra actual</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>En la pestanya actual</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Obre enllaços des de programes:</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Usa servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (segur)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (transparent)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Nom de la màquina:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avançat</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Full d&apos;estil:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Habilita la memòria cau de xarxa</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Mida màxima:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>S&apos;ha de reiniciar</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>La configuració de la memòria cau de xarxa ha canviat. S&apos;ha de reiniciar el navegador per tenir-ho en compte.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>S&apos;està carregant...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Visualitza</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Ajusta les línies</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Codi font de la pàgina %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Mostra la barra de pestanyes</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Oculta la barra de pestanyes</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplica la pestanya</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Tanca la pestanya</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Tanca les &amp;altres pestanyes</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recarrega la pestanya</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recarrega totes les pestanyes</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Pestanyes desades</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Realment voleu tancar aquesta pàgina?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Heu modificat aquesta pàgina i les modificacions es perdran en tancar-la. 
Realment voleu tancar aquesta pàgina? </translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>S&apos;està carregant...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>S&apos;està carregant %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Ha finalitzat la càrrega</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Ha fallat en carregar</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Mostra la pestanya següent</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Mostra la pestanya anterior</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Pestanyes tancades recentment</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nova pes&amp;tanya</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Tanca la pestanya</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Afegeix totes les pestanyes als punts</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Suggestions</source>
        <translation>Suggeriments</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Afegeix &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Configura els motors de cerca...</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Neteja les cerques recents</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Cap cerca recent</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Cerques recents</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Resending POST request</source>
        <translation>S&apos;està tornant a enviar la petició POST</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Per tal de mostrar el lloc, s&apos;han d&apos;enviar novament la sol licitud junt amb totes les dades, això pot donar lloc a comportaments inesperats del lloc web, p.ex. la mateixa acció podria ser realitzada una vegada més. Voleu continuar igualment?</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Error en carregar la pàgina %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>En connectar a: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Comproveu l&apos;adreça per trobar errors com ara &lt;b&gt;ww&lt;/b&gt;.arora-browser.org enlloc de &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Si l&apos;adreça és correcta, intenteu-ho comprovant la connexió de la xarxa.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Si el vostre ordinador està protegit per un tallafocs o proxy, assegureu-vos que el navegador té permés accedir a la xarxa.</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Obre en una &amp;finestra nova</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Obre en una pes&amp;tanya nova</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Desa l&apos;enlla&amp;ç</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Apunta aquest enllaç</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Copia la ubicació de l&apos;enllaç</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Obre la imatge en una &amp;finestra nova</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Obre la imatge en una pes&amp;tanya nova</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>De&amp;sa la imatge</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Copia la imatge</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>C&amp;opia la ubicació de la Imatge</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Cerca amb...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Afegeix a la barra de cerques</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Mètode no acceptat</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 mètode no està acceptat.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de cerca</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Seleccioneu el motor de cerca</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Nom del motor</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Introduïu un nom pel motor</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>S&apos;està carregant...</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>No s&apos;ha trobat</translation>
    </message>
</context>
</TS>
